@@ -40,13 +40,6 @@ The generic 'race' model requires the following interface:
     race.key_event(widget, event)  - race key handler
     race.timeout()                 - race specific update callback
 
-  Shared "Public" attributes:
-
-    race.frame                     - top level race ui widget
-    race.winopen                   - BOOL true if ui 'window' open
-    race.event                     - Event db handle
-    race.onestart                  - BOOL true if one starter/result
- 
 """
 
 import gtk
@@ -63,7 +56,6 @@ import metarace
 from metarace import tod
 from metarace import timy
 from metarace import riderdb
-from metarace import eventdb
 from metarace import scbwin
 from metarace import uiutil
 from metarace import strops
@@ -82,12 +74,12 @@ COL_DNF = 5
 COL_PLACE = 6
 
 SCB_RESNAME_WIDTH = metarace.SCB_LINELEN - 11
-SCB_RESULT_FMT = [(2, 'l'), (3, 'r'), ' ',
-                  (SCB_RESNAME_WIDTH, 'l'), ' ', (4, 'r')]
+SCB_RESULT_FMT = [(2, u'l'), (3, u'r'), u' ',
+                  (SCB_RESNAME_WIDTH, u'l'), u' ', (4, u'r')]
 
 SCB_STARTNAME_WIDTH = metarace.SCB_LINELEN - 9
-SCB_STARTERS_FMT = [(3, 'r'), ' ', (SCB_STARTNAME_WIDTH,'l'),
-                   ' ', (4,'r')]
+SCB_STARTERS_FMT = [(3, u'r'), u' ', (SCB_STARTNAME_WIDTH,u'l'),
+                   u' ', (4,u'r')]
 
 # scb function key mappings
 key_startlist = 'F3'			# show starters in table
@@ -107,7 +99,7 @@ class race(object):
     def clearplaces(self):
         """Clear places from data model."""
         for r in self.riders:
-            r[COL_PLACE] = ''
+            r[COL_PLACE] = u''
 
     def getrider(self, bib):
         """Return temporary reference to model row."""
@@ -147,21 +139,18 @@ class race(object):
             if dbr is not None:
                 for i in range(1,4):
                     nr[i] = self.meet.rdb.getvalue(dbr, i)
-                    if self.evtype == 'handicap':	# reqd?
-                        if info is not None:
+                    if self.evtype == u'handicap':	# reqd?
+                        if info:
                             nr[COL_INFO] = info
-                        #else:	# this was a hack before autospec
-                            #nr[COL_INFO] = self.meet.rdb.getvalue(dbr,
-                                                   #riderdb.COL_CAT)
             if self.evtype in ['handicap', 'keirin'] and not self.onestart:
                  self.reorderflag += 1
                  glib.timeout_add_seconds(1, self.delayed_reorder)
             return self.riders.append(nr)
         else:
             if er is not None:			# rider in model, repatch?
-                if self.evtype == 'handicap' or self.inomnium:
+                if self.evtype == u'handicap' or self.inomnium:
                     # TODO: check inomnium logic
-                    if info is not None:
+                    if not er[COL_INFO] and info: # don't overwrite if set
                         er[COL_INFO] = info
             return None
 
@@ -171,9 +160,9 @@ class race(object):
             r = self.getrider(bib)
             if r is not None:
                 r[COL_DNF] = True
-                self.log.info('Rider ' + str(bib) + ' withdrawn')
+                self.log.info(u'Rider ' + repr(bib) + u' withdrawn')
             else:
-                self.log.warn('Did not withdraw no. = ' + str(bib))
+                self.log.warn(u'Did not withdraw no. = ' + repr(bib))
         return False
 
     def delrider(self, bib):
@@ -191,20 +180,20 @@ class race(object):
         count = 0
 
         for placegroup in placestr.split():
-            for bib in placegroup.split('-'):
+            for bib in placegroup.split(u'-'):
                 if bib not in placeset:
                     placeset.add(bib)
                     r = self.getrider(bib)
                     if r is None:	# ensure rider exists at this point
-                        self.log.warn('Adding non-starter: ' + repr(bib))
+                        self.log.warn(u'Adding non-starter: ' + repr(bib))
                         self.addrider(bib) 
                         r = self.getrider(bib)
                     rank = place + self.startplace
                     r[COL_PLACE] = rank
-                    self.results.append([str(rank), r[COL_BIB],
-                       strops.fitname(r[COL_FIRSTNAME],
-                       r[COL_LASTNAME], SCB_RESNAME_WIDTH),
-                       r[COL_CLUB]])
+                    self.results.append([unicode(rank), r[COL_BIB].decode('utf-8','replace'),
+                       strops.fitname(r[COL_FIRSTNAME].decode('utf-8','replace'),
+                       r[COL_LASTNAME].decode('utf-8','replace'), SCB_RESNAME_WIDTH),
+                       r[COL_CLUB].decode('utf-8','replace')])
                     i = self.getiter(bib)
                     self.riders.swap(self.riders.get_iter(count), i)
                     count += 1
@@ -322,7 +311,7 @@ class race(object):
             auxmap = []
             cnt = 0
             for r in self.riders:
-                auxmap.append([cnt, r[COL_BIB], strops.mark2int(r[COL_INFO])])
+                auxmap.append([cnt, r[COL_BIB].decode('utf-8','replace'), strops.mark2int(r[COL_INFO].decode('utf-8','replace'))])
                 cnt += 1
             auxmap.sort(self.sort_handicap)
             self.riders.reorder([a[0] for a in auxmap])
@@ -398,9 +387,8 @@ class race(object):
         if self.winopen:
             self.meet.announce.clrall()
             self.meet.ann_title(' '.join([
-                  'Event', self.evno, ':',
-                  self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                  self.meet.edb.getvalue(self.event, eventdb.COL_INFO)]))
+                  'Event', self.evno, ':', self.event[u'pref'],
+                   self.event[u'info']]))
 
             # clear page
             self.meet.announce.linefill(1, '_')
@@ -417,21 +405,21 @@ class race(object):
                     posoft = 41
                 xtra = '    '
                 if r[COL_INFO] is not None and r[COL_INFO] != '':
-                    xtra = strops.truncpad(r[COL_INFO], 4, 'r')
+                    xtra = strops.truncpad(r[COL_INFO].decode('utf-8','replace'), 4, 'r')
 
                 clubstr = ''
                 if r[COL_CLUB] != '' and len(r[COL_CLUB]) <= 3:
-                    clubstr = ' (' + r[COL_CLUB] + ')'
-                namestr = strops.truncpad(strops.fitname(r[COL_FIRSTNAME],
-                              r[COL_LASTNAME], 25-len(clubstr),
+                    clubstr = ' (' + r[COL_CLUB].decode('utf-8','replace') + ')'
+                namestr = strops.truncpad(strops.fitname(r[COL_FIRSTNAME].decode('utf-8','replace'),
+                              r[COL_LASTNAME].decode('utf-8','replace'), 25-len(clubstr),
                               trunc=True)+clubstr, 25, elipsis=False)
 
                 placestr = '   '
                 if r[COL_PLACE] != '':
-                    placestr = strops.truncpad(r[COL_PLACE] + '.', 3)
+                    placestr = strops.truncpad(r[COL_PLACE].decode('utf-8','replace') + '.', 3)
                 elif r[COL_DNF]:
                     placestr = 'dnf'
-                bibstr = strops.truncpad(r[COL_BIB], 3, 'r')
+                bibstr = strops.truncpad(r[COL_BIB].decode('utf-8','replace'), 3, 'r')
                 self.meet.announce.postxt(curline, posoft, ' '.join([
                       placestr, bibstr, namestr, xtra]))
                 curline += 1
@@ -452,33 +440,42 @@ class race(object):
 
     def startlist_report(self):
         """Return a startlist report."""
+        ret = []
         sec = printing.section()
-        sec.heading = ' '.join([
-                      'Event', self.evno, ':',
-                  self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                  self.meet.edb.getvalue(self.event, eventdb.COL_INFO),
-                      '- Start List'])
+        sec.heading = u' '.join([
+                      u'Event', self.evno, u':', self.event[u'pref'],
+                         self.event[u'info'],
+                      u'- Start List'])
+        lapstring = strops.lapstring(self.event[u'laps'])
+        substr = u' '.join([lapstring, self.event[u'dist'],
+                             self.event[u'prog']]).strip()
+        if substr:
+            sec.subheading = substr
+
         self.reorder_handicap()
         sec.lines = []
         cnt = 0
         for r in self.riders:
-            rno = r[COL_BIB]
-            inf = r[COL_INFO]
-            rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
-                                       r[COL_CLUB])
+            rno = r[COL_BIB].decode('utf-8','replace')
+            inf = r[COL_INFO].decode('utf-8','replace')
+            if self.evtype in [u'keirin', u'sprint']: # encirc draw no
+                inf = strops.drawno_encirc(inf)
+            rname = strops.resname(r[COL_FIRSTNAME].decode('utf-8','replace'), r[COL_LASTNAME].decode('utf-8','replace'),
+                                       r[COL_CLUB].decode('utf-8','replace'))
             sec.lines.append([None, rno, rname, inf, None, None])
             cnt += 1
         if cnt > 0:
             sec.lines.append([None, None, None])
             sec.lines.append([None, None, 'Total riders: ' + str(cnt)])
-        return sec
+        ret.append(sec)
+        return ret
 
     def get_startlist(self):
         """Return a list of bibs in the rider model."""
         ret = []
         for r in self.riders:
-            ret.append(r[COL_BIB])
-        return ' '.join(ret)
+            ret.append(r[COL_BIB].decode('utf-8','replace'))
+        return u' '.join(ret)
 
     def saveconfig(self):
         """Save race to disk."""
@@ -508,9 +505,9 @@ class race(object):
             bf = ''
             if r[COL_DNF]:
                 bf='True'
-            slice = [r[COL_INFO], bf, r[COL_PLACE]]
+            slice = [r[COL_INFO].decode('utf-8','replace'), bf, r[COL_PLACE].decode('utf-8','replace')]
             cw.set('riders', r[COL_BIB], 
-                ','.join(map(lambda i: str(i).replace(',', '\\,'), slice)))
+                ','.join(map(lambda i: unicode(i).replace(',', '\\,'), slice)))
         cw.set('event', 'id', EVENT_ID)
         self.log.debug('Saving race config to: ' + self.configpath)
         with open(self.configpath, 'wb') as f:
@@ -579,7 +576,7 @@ class race(object):
             ns = se.get_text()
             if ns != self.series:
                 self.series = ns
-                self.meet.edb.editevent(self.event, series=ns)
+                self.event[u'seri'] = ns
 
             # xfer starters if not empty
             slist = strops.reformat_riderlist(
@@ -654,10 +651,8 @@ class race(object):
         tp = 'Time:'
         if self.timetype == '200m':
             tp = '200m:'
-        self.meet.scbwin = scbwin.scbtimer(self.meet.scb,
-                   self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                   self.meet.edb.getvalue(self.event, eventdb.COL_INFO),
-                                           tp)
+        self.meet.scbwin = scbwin.scbtimer(self.meet.scb, self.event[u'pref'],
+                                           self.event[u'info'], tp)
         self.timerwin = True
         self.meet.scbwin.reset()
         if self.timerstat == 'finished':
@@ -700,7 +695,8 @@ class race(object):
 
     def do_places(self):
         """Update model and show race result on scoreboard."""
-        self.placexfer(self.ctrl_places.get_text())
+        ##self.placexfer(self.ctrl_places.get_text())
+        secs = self.result_report()	# NOTE: calls into placexfer
         self.timerwin = False
         tp = 'Time:'
         if self.start is not None and self.finish is None:
@@ -719,13 +715,26 @@ class race(object):
                                   timepfx=tp, timestr=ts,pagesz=5)
             self.meet.scbwin.reset()
             self.doscbplaces = False
+            self.meet.announce.gfx_overlay(1)
+            self.meet.announce.gfx_set_title(u'Result: ' 
+                                + self.event[u'pref'] + u' '
+                                + self.event[u'info'])
+            if len(secs) > 0:
+                for l in secs[0].lines:
+                    self.meet.announce.gfx_add_row([l[0], l[2], l[4]])
         self.setfinished()
 
     def do_startlist(self):
         """Show start list on scoreboard."""
+
+        self.reorder_handicap()
         self.meet.scbwin = None
         self.timerwin = False
         startlist = []
+        self.meet.announce.gfx_overlay(1)
+        self.meet.announce.gfx_set_title(u'Startlist: ' 
+                            + self.event[u'pref'] + u' '
+                            + self.event[u'info'])
         for r in self.riders:
             if not r[5]:
                 nfo = r[4]			# Try info field
@@ -733,6 +742,14 @@ class race(object):
                     nfo = r[3]			# fall back on club/affil
                 startlist.append([r[0], strops.fitname(r[1], r[2],
                                  SCB_STARTNAME_WIDTH), nfo])
+                inf = r[COL_INFO].decode('utf-8','replace').strip()
+                if self.evtype in [u'keirin', u'sprint']: # encirc draw no
+                    inf = strops.drawno_encirc(inf)
+                self.meet.announce.gfx_add_row([r[0], 
+                                          strops.resname(r[1].decode('utf-8'),
+                                                r[2].decode('utf-8'),
+                                                r[3].decode('utf-8')),
+                                                inf])
         self.meet.scbwin = scbwin.scbtable(self.meet.scb,
                              self.meet.racenamecat(self.event),
                              SCB_STARTERS_FMT, startlist)
@@ -765,7 +782,7 @@ class race(object):
             else:
                 # rider still in the race?
                 if lr[COL_DNF]:
-                    self.log.error('DNF rider in places: ' + repr(no))
+                    self.log.error(u'DNF rider in places: ' + repr(no))
                     ret = False
         return ret
 
@@ -776,7 +793,6 @@ class race(object):
             entry.set_text(places)
             self.do_places()
             glib.idle_add(self.delayed_announce)
-            self.log.info('TESTING: export to db.')
             self.meet.delayed_export() ## check this is ok here
         else:
             self.log.error('Places not updated.')
@@ -814,7 +830,7 @@ class race(object):
 
     def update_expander_lbl_cb(self):
         """Update race info expander label."""
-        self.info_expand.set_label('Race Info : ' 
+        self.info_expand.set_label(u'Race Info : ' 
                     + self.meet.racenamecat(self.event, 64))
 
     def eliminate(self, bib):
@@ -827,40 +843,51 @@ class race(object):
                 if bib not in strops.reformat_biblist(oplaces).split():
                     self.ctrl_places.set_text(bib + ' ' + oplaces)
                     ret = True
-                    rstr = r[COL_BIB] + ' ' + strops.fitname(r[COL_FIRSTNAME],
-                                                      r[COL_LASTNAME],
-                                          metarace.SCB_LINELEN-6-len(r[COL_BIB]))
+                    fname = r[COL_FIRSTNAME].decode('utf-8','replace')
+                    lname = r[COL_LASTNAME].decode('utf-8','replace')
+                    club = r[COL_CLUB].decode('utf-8','replace')
+                    rstr = r[COL_BIB] + u' ' + strops.fitname(
+                                fname, lname, metarace.SCB_LINELEN-6-len(r[COL_BIB].decode('utf-8','replace')))
                     self.meet.scbwin = scbwin.scbintsprint(self.meet.scb,
-                      self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                      self.meet.edb.getvalue(self.event, eventdb.COL_INFO),
-                                   ['Out: ', (metarace.SCB_LINELEN-5, 'l')],
+                          self.event[u'pref'], self.event[u'info'],
+                                   [u'Out: ', (metarace.SCB_LINELEN-5, u'l')],
                                    [ [rstr] ])
                     self.meet.scbwin.reset()
+                    self.meet.gemini.reset_fields()
+                    self.meet.gemini.set_bib(bib)
+                    self.meet.gemini.show_brt()
+
+                    self.meet.announce.gfx_overlay(2)
+                    self.meet.announce.gfx_set_title(
+                                        self.event[u'pref'] + u' '
+                              + self.event[u'info'] + u' - Eliminated:')
+                    self.meet.announce.gfx_add_row([bib, 
+                                strops.resname(fname, lname, club),''])
                     # and announce it:
                     nrstr = strops.truncpad(strops.resname_bib(
-                                         r[COL_BIB], r[COL_FIRSTNAME],
-                                         r[COL_LASTNAME], r[COL_CLUB]), 60)
-                    self.meet.announce.postxt(21, 0, 'Out: ' + nrstr)
+                                         r[COL_BIB].decode('utf-8','replace'), r[COL_FIRSTNAME].decode('utf-8','replace'),
+                                         r[COL_LASTNAME].decode('utf-8','replace'), r[COL_CLUB].decode('utf-8','replace')), 60)
+                    self.meet.announce.postxt(21, 0, u'Out: ' + nrstr)
                 else:
-                    self.log.error('Rider in places or eliminated: ' + repr(bib))
+                    self.log.error(u'Rider in places or eliminated: ' + repr(bib))
             else:
-                self.log.error('Cannot eliminate dnf rider: ' + repr(bib))
+                self.log.error(u'Cannot eliminate dnf rider: ' + repr(bib))
         else:
-            self.log.error('Cannot eliminate non-starter: ' + repr(bib))
+            self.log.error(u'Cannot eliminate non-starter: ' + repr(bib))
 
         return ret
 
     def editent_cb(self, entry, col):
         """Shared event entry update callback."""
-        if col == eventdb.COL_PREFIX:
-            self.meet.edb.editevent(self.event, prefix=entry.get_text())
-        elif col == eventdb.COL_INFO:
-            self.meet.edb.editevent(self.event, info=entry.get_text())
+        if col == u'pref':
+            self.event[u'pref'] = entry.get_text().decode('utf-8', 'replace')
+        elif col == u'info':
+            self.event[u'info'] = entry.get_text().decode('utf-8', 'replace')
         self.update_expander_lbl_cb()
 
     def editcol_cb(self, cell, path, new_text, col):
         """Startlist cell update callback."""
-        new_text = new_text.strip()
+        new_text = new_text.decode('utf-8','replace').strip()
         if col == COL_BIB:
             if new_text.isalnum():
                 if self.getrider(new_text) is None:
@@ -875,9 +902,10 @@ class race(object):
 
     def editcol_db(self, cell, path, new_text, col):
         """Cell update with writeback to meet."""
-        new_text = new_text.strip()
-        self.riders[path][col] = new_text.strip()
-        glib.idle_add(self.meet.rider_edit, self.riders[path][COL_BIB],
+        new_text = new_text.decode('utf-8','replace').strip()
+        self.riders[path][col] = new_text
+        glib.idle_add(self.meet.rider_edit,
+                      self.riders[path][COL_BIB].decode('utf-8','replace'),
                                            self.series, col, new_text)
 
     def gotorow(self, i=None):
@@ -911,8 +939,8 @@ class race(object):
             self.log_elapsed()
             if self.timerwin and type(self.meet.scbwin) is scbwin.scbtimer:
                 self.showtimer()
-                if self.start is not None:
-                    self.meet.gemini.rtick(self.finish - self.start, 2)
+                #if self.start is not None:
+                    #self.meet.gemini.rtick(self.finish - self.start, 2)
             glib.idle_add(self.delayed_announce)
 
     def timercb(self, e):
@@ -975,16 +1003,16 @@ class race(object):
         """Generator function to export a final result."""
         ft = None
         for r in self.riders:
-            bib = r[COL_BIB]
+            bib = r[COL_BIB].decode('utf-8','replace')
             rank = None
             info = ''
             if self.evtype in ['handicap', 'sprint']:
                 # include handicap and previous win info
-                info = r[COL_INFO].strip()
+                info = r[COL_INFO].decode('utf-8','replace').strip()
             if self.onestart:
                 if not r[COL_DNF]:
                     if r[COL_PLACE] is not None and r[COL_PLACE] != '':
-                        rank = int(r[COL_PLACE])
+                        rank = int(r[COL_PLACE].decode('utf-8','replace'))
                 else:
                     rank = 'dnf'    # only handle did not finish for now
             time = None
@@ -995,20 +1023,25 @@ class race(object):
 
     def result_report(self):
         """Return a list of printing sections containing the race result."""
+        self.placexfer(self.ctrl_places.get_text())
         ret = []
         sec = printing.section()
-        sec.heading = 'Event ' + self.evno + ': ' + ' '.join([
-                       self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                       self.meet.edb.getvalue(self.event, eventdb.COL_INFO)
-                              ]).strip()
+        sec.heading = u'Event ' + self.evno + u': ' + u' '.join([
+                          self.event[u'pref'], self.event[u'info'] ]).strip()
         sec.lines = []
+        lapstring = strops.lapstring(self.event[u'laps'])
+        substr = u' '.join([lapstring, self.event[u'dist'],
+                             self.event[u'prog']]).strip()
+        if substr:
+            sec.subheading = substr
+
         if self.timerstat != 'finished':
             # emit a 'start list' -> tempo!
             for r in self.riders:
-                rno = r[COL_BIB]
-                rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
-                                       r[COL_CLUB])
-                inf = r[COL_INFO].strip()
+                rno = r[COL_BIB].decode('utf-8','replace')
+                rname = strops.resname(r[COL_FIRSTNAME].decode('utf-8','replace'), r[COL_LASTNAME].decode('utf-8','replace'),
+                                       r[COL_CLUB].decode('utf-8','replace'))
+                inf = r[COL_INFO].decode('utf-8','replace').strip()
                 sec.lines.append([None, rno, rname, None, None, inf])
         else:
             first = True
@@ -1016,15 +1049,17 @@ class race(object):
             if self.finish is not None:
                 fs = self.time_lbl.get_text().strip()
             for r in self.riders:
-                rno = r[COL_BIB]
-                rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
-                                       r[COL_CLUB])
-                inf = r[COL_INFO].strip()
+                rno = r[COL_BIB].decode('utf-8','replace')
+                rname = strops.resname(r[COL_FIRSTNAME].decode('utf-8','replace'), r[COL_LASTNAME].decode('utf-8','replace'),
+                                       r[COL_CLUB].decode('utf-8','replace'))
+                inf = r[COL_INFO].decode('utf-8','replace').strip()
+                if self.evtype in [u'keirin', u'sprint']: # encirc draw no
+                    inf = strops.drawno_encirc(inf)
                 plstr = ''
                 if r[COL_DNF]:
                     plstr = 'dnf'
                 elif self.onestart and r[COL_PLACE] != '':
-                    plstr = r[COL_PLACE] + '.'
+                    plstr = r[COL_PLACE].decode('utf-8','replace') + '.'
                 if plstr:	# don't emit a row for unplaced riders
                     if not first:
                         # ( this is problematic - handicap is really a propert of the rider
@@ -1036,59 +1071,6 @@ class race(object):
         ret.append(sec)
         return ret
 
-    def result_export(self, f):
-        """Export results to supplied file handle."""
-        # this should eventually go away...
-        cr = csv.writer(f)
-        df = ''
-        dist = self.meet.get_distance(self.distance, self.units)
-        if dist:
-            df = str(dist) + 'm'
-        cr.writerow(['Event ' + self.evno, '',
-                     ' '.join([
-                       self.meet.edb.getvalue(self.event, eventdb.COL_PREFIX),
-                       self.meet.edb.getvalue(self.event, eventdb.COL_INFO)
-                              ]).strip(),
-                     '',
-                     df])
-        if self.timerstat != 'finished':
-            # emit a start list -> tempo!
-            for r in self.riders:
-                rno = r[COL_BIB]
-                rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
-                                       r[COL_CLUB])
-                inf = r[COL_INFO].strip()
-                if inf != '':
-                    inf = "'" + inf
-                cr.writerow(['', rno, rname, inf])
-        else:
-            first = True
-            fs = ''
-            if self.finish is not None:
-                fs = "'" + self.time_lbl.get_text().strip()
-            for r in self.riders:
-                rno = r[COL_BIB]
-                rname = strops.resname(r[COL_FIRSTNAME], r[COL_LASTNAME],
-                                       r[COL_CLUB])
-                inf = r[COL_INFO].strip()
-                if inf != '':
-                    inf = "'" + inf
-                plstr = ''
-                if r[COL_DNF]:
-                    plstr = 'dnf'
-                elif self.onestart and r[COL_PLACE] != '':
-                    plstr = "'" + r[COL_PLACE] + '.'
-                if not first:
-                    cr.writerow([plstr,rno,rname,inf])
-                else:
-                    cr.writerow([plstr,rno,rname,inf,fs])
-                    first = False
-            #if first:
-                #if fs != '':
-                    #cr.writerow(['','[No Places]','',fs])
-                #else:
-                    #cr.writerow(['','[No Result]'])
-
     def destroy(self):
         """Signal race shutdown."""
         self.frame.destroy()
@@ -1112,10 +1094,10 @@ class race(object):
 
         """
         self.meet = meet
-        self.event = event	# Note: now a treerowref
-        self.evno = meet.edb.getvalue(event, eventdb.COL_EVNO)
-        self.evtype = meet.edb.getvalue(event, eventdb.COL_TYPE)
-        self.series = meet.edb.getvalue(event, eventdb.COL_SERIES)
+        self.event = event
+        self.evno = event[u'evid']
+        self.evtype = event[u'type']
+        self.series = event[u'seri']
         self.configpath = meet.event_configfile(self.evno)
 
         self.log = logging.getLogger('race')
@@ -1162,21 +1144,16 @@ class race(object):
         b.get_object('race_info_evno').set_text(self.evno)
         self.showev = b.get_object('race_info_evno_show')
         self.prefix_ent = b.get_object('race_info_prefix')
-        self.prefix_ent.connect('changed', self.editent_cb,
-                                 eventdb.COL_PREFIX)
-        self.prefix_ent.set_text(self.meet.edb.getvalue(
-                   self.event, eventdb.COL_PREFIX))
+        self.prefix_ent.connect('changed', self.editent_cb,u'pref')
+        self.prefix_ent.set_text(self.event[u'pref'])
         self.info_ent = b.get_object('race_info_title')
-        self.info_ent.connect('changed', self.editent_cb,
-                               eventdb.COL_INFO)
-        self.info_ent.set_text(self.meet.edb.getvalue(
-                   self.event, eventdb.COL_INFO))
+        self.info_ent.connect('changed', self.editent_cb,u'info')
+        self.info_ent.set_text(self.event[u'info'])
 
         self.time_lbl = b.get_object('race_info_time')
         self.time_lbl.modify_font(pango.FontDescription("monospace bold"))
         self.type_lbl = b.get_object('race_type')
-        self.type_lbl.set_text(self.meet.edb.getvalue(
-                                 self.event, eventdb.COL_TYPE).capitalize())
+        self.type_lbl.set_text(self.event[u'type'].capitalize())
 
         # ctrl pane
         self.stat_but = b.get_object('race_ctrl_stat_but')
