@@ -606,14 +606,25 @@ class rms(object):
         catname = u''
         subhead = u''
         if cat is not None:
-           dbr = self.meet.rdb.getrider(cat,u'cat')
-           if dbr is not None:
-               catname = self.meet.rdb.getvalue(dbr,
-                                         riderdb.COL_FIRST)
-               subhead = self.meet.rdb.getvalue(dbr,
-                                         riderdb.COL_LAST)
+            dbr = self.meet.rdb.getrider(cat,u'cat')
+            if dbr is not None:
+                catname = self.meet.rdb.getvalue(dbr,
+                                          riderdb.COL_FIRST)
+                subhead = self.meet.rdb.getvalue(dbr,
+                                          riderdb.COL_LAST)
         else:
             cat = u''	# match all riders
+
+        catcache = {u'':None}
+        if cat == u'':
+            for c in self.meet.rdb.listcats(self.series):
+                if c != u'':
+                    catnm = c
+                    dbr = self.meet.rdb.getrider(c,u'cat')
+                    if dbr is not None:
+                        catnm = self.meet.rdb.getvalue(dbr,
+                                         riderdb.COL_FIRST)
+                    catcache[c] = catnm
         ret = []
         sec = printing.section()
         sec.heading = 'Startlist'
@@ -624,19 +635,23 @@ class rms(object):
         rcnt = 0
         cat = self.ridercat(cat)
         for r in self.riders:
-            if cat is None or self.ridercat(r[COL_CAT]) == cat:
+            rcat = r[COL_CAT].decode('utf-8').upper()
+            if cat == u'' or rcat == cat:
                 ucicode = None
-                dbr = self.meet.rdb.getrider(r[COL_BIB],self.series)
+                dbr = self.meet.rdb.getrider(r[COL_BIB].decode('utf-8'),
+                                             self.series)
                 if dbr is not None:
                     ucicode = self.meet.rdb.getvalue(dbr,
                                              riderdb.COL_UCICODE)
+                if not ucicode and cat == u'':
+                    ucicode = catcache[rcat] # try and fill cat
                 comment = None
-                if r[COL_CAT] == 'U23':
-                    comment = '*' 
+                #if r[COL_CAT] == 'U23': # hack -> should be config'ble
+                    #comment = '*' 
                 if not r[COL_INRACE]:
-                    comment = r[COL_COMMENT].decode('utf-8')
-                    if comment == '':
-                        comment = 'dnf'
+                    cmt = r[COL_COMMENT].decode('utf-8')
+                    if cmt == u'dns':
+                        comment = cmt
                 sec.lines.append([comment, r[COL_BIB].decode('utf-8'),
                                        r[COL_NAMESTR].decode('utf-8'),
                                            ucicode])
@@ -765,7 +780,13 @@ class rms(object):
                 subhead = self.meet.rdb.getvalue(dbr,
                                           riderdb.COL_LAST)
             sec = printing.section()
-            sec.heading = 'Result'
+            if self.timerstat == 'finished':
+                sec.heading = 'Result'
+            elif self.timerstat in ['running', 'ready']:
+                sec.heading = 'Race in Progress'
+            else:
+                sec.heading = 'Provisional Result'
+
             if catname:
                 sec.heading += u': ' + catname
                 sec.subheading = subhead
@@ -829,30 +850,53 @@ class rms(object):
 
     def result_report(self):
         """Return a race result report."""
-        if len(self.cats) > 1:
-            return self.catresult_report()	# hack mode for baw baw
+        if self.event[u'type'] != u'rhcp' and len(self.cats) > 1:
+            return self.catresult_report() # TODO: convert to shared result
 
         self.recalculate()
         ret = []
         wt = None
+        we = None
         dofastest = False	# ftime for handicap races
         fastest = None
+        vfastest = None
+        curelap = None
+        if self.start is not None:	# virtual bunch time
+            curelap = (tod.tod('now') - self.start).truncate(0)
         fastestbib = None
         totcount = 0
         dnscount = 0
         dnfcount = 0
+        hdcount = 0
         fincount = 0
         lcomment = ''
+        catcache = {u'':None}
+        for c in self.meet.rdb.listcats(self.series):
+            if c != u'':
+                catnm = c
+                dbr = self.meet.rdb.getrider(c,u'cat')
+                if dbr is not None:
+                    catnm = self.meet.rdb.getvalue(dbr,
+                                     riderdb.COL_FIRST)
+                catcache[c] = catnm
         lt = None
         if self.timerstat != 'idle':
             sec = printing.section()
+            if self.timerstat == 'finished':
+                sec.heading = 'Result'
+            elif self.timerstat in ['running', 'ready']:
+                sec.heading = 'Race in Progress'
+            else:
+                sec.heading = 'Provisional Result'
             
             first = True
             for r in self.riders:
                 totcount += 1
-                bstr = r[COL_BIB]
-                nstr = r[COL_NAMESTR]
-                cstr = r[COL_CAT]
+                bstr = r[COL_BIB].decode('utf-8')
+                nstr = r[COL_NAMESTR].decode('utf-8')
+                cstr = r[COL_CAT].decode('utf-8')
+                if cstr.upper() in catcache:
+                    cstr = catcache[cstr.upper()]
                 pstr = ''
                 tstr = ''
                 dstr = ''
@@ -876,12 +920,19 @@ class rms(object):
                             dofastest = True	# will need to report!
                             et = bt - r[COL_STOFT]
                             tstr = et.rawtime(0)
+                            if we is None:
+                                we = et
                         if fastest is None or et < fastest:
                             fastest = et
                             fastestbib = r[COL_BIB]
+                    else:	# check virtual finish time
+                        if r[COL_STOFT] is not None:
+                            vt = curelap - r[COL_STOFT]
+                            if vfastest is None or vt < vfastest:
+                                vfastest = vt
                     lt = bt
                 else:
-                    comment = r[COL_COMMENT]
+                    comment = r[COL_COMMENT].decode('utf-8')
                     if comment == '':
                         comment = 'dnf'
                     if comment != lcomment:
@@ -889,40 +940,58 @@ class rms(object):
                     lcomment = comment
                     if comment == 'dns':
                         dnscount += 1
+                    elif comment == 'hd':
+                        hdcount += 1
                     else:
                         dnfcount += 1
                     pstr = strops.truncpad(comment, 4)
                 sec.lines.append([pstr, bstr, nstr, cstr, tstr, dstr])
-            if wt is not None:
-                sec.lines.append([None, None, None])
-                sec.lines.append([None, None, 'Race time: ' + wt.rawtime(0)])
-            if dofastest:
-                ftr = self.getrider(fastestbib)
-                fts = ''
-                if ftr is not None:
-                    fts = strops.truncpad(ftr[COL_NAMESTR] 
-                                          + ' ' + ftr[COL_CAT], 44)
-                sec.lines.append([None, None, 
-                       'Fastest time: ' + fastest.rawtime(0)
-                           + '  ' + fastestbib + '  ' + fts])
-            sec.lines.append([None, None, None])
-            sec.lines.append([None, None,
-                             'Total riders: ' + str(totcount)])
-            sec.lines.append([None, None, 
-                             'Did not start: ' + str(dnscount)])
-            sec.lines.append([None, None,
-                             'Did not finish: ' + str(dnfcount)])
-            sec.lines.append([None, None,
-                             'Finishers: ' + str(fincount)])
-            residual = totcount - (fincount + dnfcount + dnscount)
-            if residual > 0:
-                sec.lines.append([None, None,
-                          'Unaccounted for: ' + str(residual)])
-            #if len(self.comment) > 0:
-                #ret.append('')
-                #for cl in self.comment:
-                    #ret.append('* ' + strops.truncpad(cl.strip(), 64))
             ret.append(sec)
+            sec = printing.bullet_text()
+            if wt is not None:
+                sec.lines.append([None, u'Race time: ' + wt.rawtime(0)])
+                if we is None:
+                    we = wt
+                dval = self.meet.get_distance()
+                if dval is not None:
+                    sec.lines.append([None, u'Average speed of the winner: '
+                                        + we.speedstr(1000.0*dval)])
+            if dofastest:
+                if vfastest and vfastest < fastest:
+                    self.log.info(u'Fastest time not yet available.')
+                else:
+                    ftr = self.getrider(fastestbib)
+                    fts = ''
+                    if ftr is not None:
+                        fts = strops.truncpad(ftr[COL_NAMESTR] 
+                                              + ' ' + ftr[COL_CAT], 44)
+                    sec.lines.append([None,
+                           'Fastest time: ' + fastest.rawtime(0)
+                               + '  ' + fastestbib + '  ' + fts])
+            sec.lines.append([None,
+                              u'Number of starters: '
+                              + unicode(totcount-dnscount)])
+            if hdcount > 0:
+                sec.lines.append([None,
+                              u'Riders finishing out of time limits: '
+                              + unicode(hdcount)])
+            if dnfcount > 0:
+                sec.lines.append([None,
+                              u'Riders abandoning the race: '
+                              + unicode(dnfcount)])
+            residual = totcount - (fincount + dnfcount + dnscount + hdcount)
+            if residual > 0:
+                self.log.info(u'Unaccounted for: ' + unicode(residual))
+                #sec.lines.append([None, None,
+                          #'Unaccounted for: ' + str(residual)])
+            ret.append(sec)
+            
+            if len(self.comment) > 0:	# ADD Decisions of comm panel...
+                sec = printing.bullet_text()
+                sec.heading = 'Decisions of the Commissaires Panel'
+                for cl in self.comment:
+                    sec.lines.append([None, cl.strip()])
+                ret.append(sec)
         else:
             pass
             #ret.append('-- Not Started --')
