@@ -1004,6 +1004,7 @@ class roadmeet:
         cw.set(u'meet', u'uscbport', self.uscbport)
         cw.set(u'meet', u'uscbchan', self.uscbchan)
         cw.set(u'meet', u'timer', self.timer_port)
+        cw.set(u'meet', u'rfidlvl', self.rfidlvl)
         cw.set(u'meet', u'alttimer', self.alttimer_port)
 
         cw.set(u'meet', u'title', self.title_str)
@@ -1063,6 +1064,7 @@ class roadmeet:
                u'distance':u'',
                u'docindex':u'0',
                u'timer':u'',
+               u'rfidlvl':[u'20', u'30'],
                u'alttimer':u'',
                u'resultnos':u'Yes',
                u'uscbport':u'',
@@ -1102,6 +1104,14 @@ class roadmeet:
 
         # set timer port (decoder)
         self.set_timer(cr.get(u'meet', u'timer'))
+        boxlvl = u'20'
+        stalvl = u'30'
+        nv = cr.get(u'meet', u'rfidlvl')
+        if len(nv) > 1:
+            boxlvl = nv[0]
+            stalvl = nv[1]
+        self.timer.setlvl(boxlvl, stalvl)
+        self.rfidlvl = [boxlvl, stalvl]
 
         # set alt timer port (timy)
         nport = cr.get(u'meet', u'alttimer')
@@ -1301,6 +1311,7 @@ class roadmeet:
         # hardware connections
         self.timer = thbc.thbc()	# default is Tag, may change later
         self.timer_port = u''
+        self.rfidlvl = [u'20',u'30']
         self.alttimer = timy.timy()
         self.alttimer_port = u''
         self.uscbport = u''
